@@ -5,7 +5,7 @@
 #include<ctime>
 
 
-#define INT_MIN (-INT_MAX - 1)
+
 
 using namespace Rcpp;
 using namespace arma;
@@ -196,7 +196,7 @@ Rcpp::List correct_one_gene(const Rcpp::List& Xlist, const Rcpp::List& RList,
   }
   field<vec> Muu(Eu);
   vec elbo_vec(maxIter);
-  elbo_vec(0) = INT_MIN;
+  elbo_vec(0) = -1e15;
   int iter;
   
   Rprintf("Finish variable initialization \n");
